confirm_distinct: Confirm Distinct

View source: R/confirm_distinct.R

confirm_distinctR Documentation

Confirm Distinct

Description

Confirm whether the rows of a data frame can be uniquely identified by the keys in the selected columns. Also reports whether the dataframe has duplicates. If so, it is best to remove duplicates and re-run the function.

Usage

confirm_distinct(.data, ...)

Arguments

.data

A dataframe

...

(ID) columns

Value

a Logical value invisibly with description printed to console

Examples

iris %>% confirm_distinct(Species, Sepal.Width)

validata documentation built on Feb. 26, 2026, 5:06 p.m.