diagnose: diagnose

View source: R/diagnose.R

diagnoseR Documentation

diagnose

Description

Pipe in a dataframe to return a diagnosis of its missing and unique values for each columns. Default behavior is to diagnose all columns, but a subset can be specified in the dots with tidyselect.

Usage

diagnose(df, ...)

Arguments

df

dataframe

...

tidyselect

Details

this function is inspired by the excellent dlookr package. It takes a dataframe and returns a summary of unique and missing values of the columns.

Value

dataframe summary

Examples

diagnose(iris)


validata documentation built on Feb. 26, 2026, 5:06 p.m.