diagnose_category: diagnose category

diagnose_categoryR Documentation

diagnose category

Description

counts the distinct entries of categorical variables. The max_distinct argument limits the scope to categorical variables with a maximum number of unique entries, to prevent overflow.

Usage

diagnose_category(.data, ..., max_distinct = 5)

Arguments

.data

dataframe

...

tidyselect

max_distinct

integer

Value

dataframe

Examples

diagnose_category(iris)

validata documentation built on Feb. 26, 2026, 5:06 p.m.